Package: sjPlot
Type: Package
Encoding: UTF-8
Title: Data Visualization for Statistics in Social Science
Version: 2.9.0
Authors@R: c(
    person("Daniel", "Lüdecke", email = "d.luedecke@uke.de", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-8895-3206")),
    person("Alexander", "Bartel", role = "ctb", comment = c(ORCID = "0000-0002-1280-6138")),
    person("Carsten", "Schwemmer", email = "carsten.schwemmer@uni-bamberg.de", role = "ctb"),
    person(given = "Chuck", family = "Powell", role = "ctb", email = "ibecav@gmail.com", comment = c(ORCID = "0000-0002-3606-2188")),
    person(given = "Amir", family = "Djalovski", role = "ctb", email = "Amir.DJV@gmail.com"),
    person(given = "Johannes", family = "Titz", role = "ctb", email = "johannes@titz.science", comment = c(ORCID = "0000-0002-1102-5719")))
Maintainer: Daniel Lüdecke <d.luedecke@uke.de>
Description: Collection of plotting and table output functions for data
    visualization. Results of various statistical analyses (that are commonly used
    in social sciences) can be visualized using this package, including simple and
    cross tabulated frequencies, histograms, box plots, (generalized) linear models,
    mixed effects models, principal component analysis and correlation matrices,
    cluster analyses, scatter plots, stacked scales, effects plots of regression
    models (including interaction terms) and much more. This package supports
    labelled data.
License: GPL-3
Depends: R (>= 4.1)
Imports: graphics, grDevices, stats, utils, bayestestR (>= 0.16.1),
        datawizard (>= 1.1.0), dplyr, ggeffects, ggplot2 (>= 3.2.0),
        knitr, insight (>= 1.3.1), parameters (>= 0.27.0), performance
        (>= 0.15.0), purrr, rlang, scales, sjlabelled (>= 1.1.2),
        sjmisc (>= 2.8.2), sjstats (>= 0.17.8), tidyr (>= 1.0.0)
Suggests: brms, car, clubSandwich, cluster, cowplot, effects, haven,
        GPArotation, ggrepel, glmmTMB, gridExtra, ggridges, httr, lme4,
        MASS, nFactors, pscl, psych, rmarkdown, rstanarm, sandwich,
        splines, survey, TMB, testthat
URL: https://strengejacke.github.io/sjPlot/
BugReports: https://github.com/strengejacke/sjPlot/issues
RoxygenNote: 7.3.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-07-10 18:10:34 UTC; DL
Author: Daniel Lüdecke [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8895-3206>),
  Alexander Bartel [ctb] (ORCID: <https://orcid.org/0000-0002-1280-6138>),
  Carsten Schwemmer [ctb],
  Chuck Powell [ctb] (ORCID: <https://orcid.org/0000-0002-3606-2188>),
  Amir Djalovski [ctb],
  Johannes Titz [ctb] (ORCID: <https://orcid.org/0000-0002-1102-5719>)
Repository: CRAN
Date/Publication: 2025-07-10 19:00:05 UTC
Built: R 4.6.0; ; 2026-04-26 16:14:37 UTC; unix
