# Generated by roxygen2: do not edit by hand

S3method(knit_print,sjTable)
S3method(knit_print,sjt_descr)
S3method(knit_print,sjt_frq)
S3method(knit_print,sjt_grpdescr)
S3method(knit_print,sjt_grpmean)
S3method(knit_print,sjt_grpmeans)
S3method(knit_print,sjt_mwu)
S3method(knit_print,sjt_reliab)
S3method(print,sjTable)
S3method(print,sjt_descr)
S3method(print,sjt_equi_test)
S3method(print,sjt_frq)
S3method(print,sjt_grpdescr)
S3method(print,sjt_grpmean)
S3method(print,sjt_grpmeans)
S3method(print,sjt_mwu)
S3method(print,sjt_reliab)
export(css_theme)
export(dist_chisq)
export(dist_f)
export(dist_norm)
export(dist_t)
export(font_size)
export(get_model_data)
export(label_angle)
export(legend_style)
export(plot_frq)
export(plot_gpt)
export(plot_grid)
export(plot_grpfrq)
export(plot_likert)
export(plot_model)
export(plot_models)
export(plot_residuals)
export(plot_scatter)
export(plot_stackfrq)
export(plot_xtab)
export(save_plot)
export(scale_color_sjplot)
export(scale_fill_sjplot)
export(set_theme)
export(show_sjplot_pals)
export(sjp.chi2)
export(sjp.poly)
export(sjplot)
export(sjplot_pal)
export(sjt.itemanalysis)
export(sjt.xtab)
export(sjtab)
export(tab_corr)
export(tab_df)
export(tab_dfs)
export(tab_fa)
export(tab_itemscale)
export(tab_model)
export(tab_pca)
export(tab_stackfrq)
export(tab_xtab)
export(theme_538)
export(theme_blank)
export(theme_sjplot)
export(theme_sjplot2)
export(view_df)
importFrom(knitr,asis_output)
importFrom(knitr,knit_print)
importFrom(rlang,.data)
importFrom(rlang,enquo)
importFrom(rlang,quo_name)
