\docType{data}
\name{efc}
\alias{efc}
\title{Sample dataset from the EUROFAMCARE project}
\description{
A SPSS sample data set, imported with the \code{\link[sjlabelled]{read_spss}} function.
}
\keyword{data}
